# netbuild
 The Python Network Building Tool (or 'netbuilder' package) is a terrific tool for students and networking
 enthusiasts alike, which provides helpful functions for IP schema creation and subnetting.  It has four
 primary modes, including a guide/walkthrough and a quick start variatn for both IPv4 and IPv6.
 
 You can use this tool to create a subnet plan for an IPv4 network, check address classes, check public and
 private addresses (as well as special addresses), expand and/or compress an IPv6 address, and check IP ranges
 or /64 network counts for an IPv6 network.
